@@ -1,14 +1,8 @@
-try:
-    from nmb.NetBIOS import NetBIOS
-    from core.winRmExec import WinRmExec
-    import ntpath
-except Exception as err:
-    from core.exception import AwdExceptions
-
-    raise AwdExceptions(str(err))
+from nmb.NetBIOS import NetBIOS
+from core.winRmExec import WinRmExec
 
 
-def GetHostName(host, timeout=30):
+def GetHostName(host, username, password, timeout=30):
     bios = NetBIOS()
     hostname = bios.queryIPForName(host, timeout=timeout)
     bios.close()
