@@ -1,13 +1,8 @@
-try:
-    import ntpath, os, random, string, time
-    from impacket.dcerpc.v5.dcomrt import DCOMConnection
-    from impacket.smbconnection import SMBConnection
-    from impacket.dcerpc.v5.dcom import wmi
-    from impacket.dcerpc.v5.dtypes import NULL
-except Exception as err:
-    from core.exception import AwdExceptions
-
-    raise AwdExceptions(str(err))
+import ntpath, random, string, time
+from impacket.dcerpc.v5.dcomrt import DCOMConnection
+from impacket.smbconnection import SMBConnection
+from impacket.dcerpc.v5.dcom import wmi
+from impacket.dcerpc.v5.dtypes import NULL
 
 
 def gen_random_string(length=10):
